@@ -12,8 +12,8 @@ def random_emoji(version="latest"):
     except ValueError:
         pass
 
-    # Unicode Standard Emoji from
-    # https://www.unicode.org/Public/emoji/
+    # Unicode Standard Emoji from https://www.unicode.org/Public/emoji/
+    # wget -q -r -np -A "emoji-test.txt" -nH --cut-dirs=1 https://www.unicode.org/Public/emoji/ && find emoji/ -type d -empty -exec rmdir {} \; 2>/dev/null
 
     try:
         with open(os.path.join(dirname, f"./emoji/{version}/emoji-test.txt"), 'r', encoding='utf-8') as f:
@@ -23,11 +23,9 @@ def random_emoji(version="latest"):
         print(f"Unicode version \"{version}\" is not supported. The following versions are currently supported:\n{', '.join(versions)}")
         exit()
 
-    emojiHex = random.choice(lines).split(';', 1)[0].strip().split()
-
     emoji = ""
 
-    for octet in emojiHex:
+    for octet in random.choice(lines).split(';', 1)[0].strip().split():
         emoji += chr(int("0x" + octet, 16))
 
     return emoji
